@@ -3,10 +3,12 @@
 #  Copyright (c) 2004-2008 Canonical
 #                2004 Michiel Sikkes
 #                2005 Martin Willemoes Hansen
+#                2010 Mohamed Amine IL Idrissi
 #  
 #  Author: Michiel Sikkes <michiel@eyesopened.nl>
 #          Michael Vogt <mvo@debian.org>
 #          Martin Willemoes Hansen <mwh@sysrq.dk>
+#          Mohamed Amine IL Idrissi <ilidrissiamine@gmail.com>
 # 
 #  This program is free software; you can redistribute it and/or 
 #  modify it under the terms of the GNU General Public License as 
@@ -29,6 +31,7 @@ import gtk
 import gtk.gdk
 import gconf
 import gobject
+gobject.threads_init()
 import glib
 
 import warnings
@@ -72,6 +75,7 @@ from Core.utils import *
 from Core.UpdateList import UpdateList
 from Core.MyCache import MyCache, NotEnoughFreeSpaceError
 from Core.MetaRelease import Dist
+from Core.AlertWatcher import AlertWatcher
 from SafeGConfClient import SafeGConfClient
 
 from DistUpgradeFetcher import DistUpgradeFetcherGtk
@@ -94,6 +98,13 @@ from MetaReleaseGObject import MetaRelease
 # file that signals if we need to reboot
 REBOOT_REQUIRED_FILE = "/var/run/reboot-required"
 
+# NetworkManager enums
+NM_STATE_UNKNOWN = 0
+NM_STATE_ASLEEP = 1
+NM_STATE_CONNECTING = 2
+NM_STATE_CONNECTED = 3
+NM_STATE_DISCONNECTED = 4
+
 class UpdateManagerDbusControler(dbus.service.Object):
     """ this is a helper to provide the UpdateManagerIFace """
     def __init__(self, parent, bus_name,
@@ -121,6 +132,10 @@ class UpdateManager(SimpleGtkbuilderApp):
     except:
         logging.exception("setlocale failed")
 
+    # Used for inhibiting power management
+    self.sleep_cookie = None
+    self.sleep_dev = None
+
     self.image_logo.set_from_icon_name("update-manager", gtk.ICON_SIZE_DIALOG)
     self.window_main.set_sensitive(False)
     self.window_main.grab_focus()
@@ -161,12 +176,12 @@ class UpdateManager(SimpleGtkbuilderApp):
     column = gtk.TreeViewColumn("Name", tr, markup=LIST_CONTENTS)
     column.set_resizable(True)
     major,minor,patch = gtk.pygtk_version
-    if (major >= 2) and (minor >= 5):
-      column_install.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
-      column_install.set_fixed_width(30)
-      column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
-      column.set_fixed_width(100)
-      self.treeview_update.set_fixed_height_mode(False)
+
+    column_install.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
+    column_install.set_fixed_width(30)
+    column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
+    column.set_fixed_width(100)
+    self.treeview_update.set_fixed_height_mode(False)
 
     self.treeview_update.append_column(column_install)
     column_install.set_visible(True)
@@ -188,14 +203,14 @@ class UpdateManager(SimpleGtkbuilderApp):
     init_proxy(self.gconfclient)
     # init show version
     self.show_versions = self.gconfclient.get_bool("/apps/update-manager/show_versions")
+    # init summary_before_name
+    self.summary_before_name = self.gconfclient.get_bool("/apps/update-manager/summary_before_name")
     # keep track when we run (for update-notifier)
     self.gconfclient.set_int("/apps/update-manager/launch_time", int(time.time()))
 
     # get progress object
-    self.progress = GtkProgress.GtkOpProgress(self.dialog_cacheprogress,
-                                              self.progressbar_cache,
-                                              self.label_cache,
-                                              self.window_main)
+    self.progress = GtkProgress.GtkOpProgressInline(
+        self.progressbar_cache_inline, self.window_main)
 
     #set minimum size to prevent the headline label blocking the resize process
     self.window_main.set_size_request(500,-1) 
@@ -204,12 +219,13 @@ class UpdateManager(SimpleGtkbuilderApp):
     # deal with no-focus-on-map
     if options.no_focus_on_map:
         self.window_main.set_focus_on_map(False)
-        self.progress._window.set_focus_on_map(False)
+        if self.progress._window:
+            self.progress._window.set_focus_on_map(False)
     # show the main window
     self.window_main.show()
     # get the install backend
-    self.install_backend = backend.backend_factory(self.window_main)
-
+    self.install_backend = backend.get_backend(self.window_main)
+    self.install_backend.connect("action-done", self._on_backend_done)
     # it can only the iconified *after* it is shown (even if the docs
     # claim otherwise)
     if options.no_focus_on_map:
@@ -218,15 +234,17 @@ class UpdateManager(SimpleGtkbuilderApp):
         self.window_main.set_urgency_hint(True)
         self.initial_focus_id = self.window_main.connect(
             "focus-in-event", self.on_initial_focus_in)
-    else:
-        self.warn_on_battery()
+    
+    # Alert watcher
+    self.alert_watcher = AlertWatcher()
+    self.alert_watcher.connect("network-alert", self._on_network_alert)
+    self.alert_watcher.connect("battery-alert", self._on_battery_alert)
 
   def on_initial_focus_in(self, widget, event):
       """callback run on initial focus-in (if started unmapped)"""
       widget.unstick()
       widget.set_urgency_hint(False)
       self.window_main.disconnect(self.initial_focus_id)
-      self.warn_on_battery()
       return False
 
   def warn_on_battery(self):
@@ -246,7 +264,7 @@ class UpdateManager(SimpleGtkbuilderApp):
     if pkg is None:
         return
     current_state = renderer.get_property("active")
-    to_install = pkg.markedInstall or pkg.markedUpgrade
+    to_install = pkg.marked_install or pkg.marked_upgrade
     renderer.set_property("active", to_install)
     # we need to update the store as well to ensure orca knowns
     # about state changes (it will not read view_func changes)
@@ -452,12 +470,44 @@ class UpdateManager(SimpleGtkbuilderApp):
       try:
           inst_count = self.cache.installCount
           self.dl_size = self.cache.requiredDownload
-          t = _("Download size: %s\n%s selected.") % (
-                                                      humanize_size(self.dl_size),inst_count)
-          self.label_downsize.set_text(t)
+          count_str = ""
+          download_str = ""
+          if inst_count > 0:
+              count_str = ngettext("%(count)s update has been selected.", 
+                                   "%(count)s updates have been selected.",
+                                   inst_count) % { 'count' : inst_count }
+          if self.dl_size != 0:
+              download_str = _("%s will be downloaded.") % (humanize_size(self.dl_size))
+              self.image_downsize.set_sensitive(True)
+              # do not set the buttons to sensitive/insensitive until NM
+              # can deal with dialup connections properly
+              #if self.alert_watcher.network_state != NM_STATE_CONNECTED:
+              #    self.button_install.set_sensitive(False)
+              #else:
+              #    self.button_install.set_sensitive(True)
+              self.button_install.set_sensitive(True)
+          else:
+              if inst_count > 0:
+                  download_str = ngettext("The update has already been downloaded, but not installed",
+                  "The updates have already been downloaded, but not installed", inst_count)
+                  self.button_install.set_sensitive(True)
+              else:
+                  download_str = _("There are no updates to install")
+                  self.button_install.set_sensitive(False)
+              self.image_downsize.set_sensitive(False)
+          # TRANSLATORS: this allows to switch the order of the count of
+          #              updates and the download size string (if needed)
+          self.label_downsize.set_text(_("%(count_str)s %(download_str)s") % {
+                  'count_str' : count_str,
+                  'download_str' : download_str})
+          self.hbox_downsize.show()
+          self.vbox_alerts.show()
       except SystemError, e:
           print "requiredDownload could not be calculated: %s" % e
-          self.label_downsize.set_markup(_("Unknown download size"))
+          self.label_downsize.set_markup(_("Unknown download size."))
+          self.image_downsize.set_sensitive(False)
+          self.hbox_downsize.show()
+          self.vbox_alerts.show()
 
   def _get_last_apt_get_update_text(self):
       """
@@ -474,13 +524,13 @@ class UpdateManager(SimpleGtkbuilderApp):
       ago_days = int( (time.time() - mtime) / (24*60*60))
       ago_hours = int((time.time() - mtime) / (60*60) )
       if ago_days > 0:
-          return ngettext("The package information was last updated %s day ago.",
-                          "The package information was last updated %s days ago.",
-                          ago_days) % ago_days
+          return ngettext("The package information was last updated %(days_ago)s day ago.",
+                          "The package information was last updated %(days_ago)s days ago.",
+                          ago_days) % { "days_ago" : ago_days, }
       elif ago_hours > 0:
-          return ngettext("The package information was last updated %s hour ago.",
-                          "The package information was last updated %s hours ago.",
-                          ago_hours) % ago_hours
+          return ngettext("The package information was last updated %(hours_ago)s hour ago.",
+                          "The package information was last updated %(hours_ago)s hours ago.",
+                          ago_hours) % { "hours_ago" : ago_hours, }
       else:
           return _("The package information was last updated less than one hour ago.")
       return None
@@ -505,9 +555,10 @@ class UpdateManager(SimpleGtkbuilderApp):
       text_label_main = _("Software updates correct errors, eliminate security vulnerabilities and provide new features.")
       if num_updates == 0:
           text_header= "<big><b>%s</b></big>"  % _("Your system is up-to-date")
-          self.label_downsize.set_text("")
-          self.notebook_details.set_sensitive(False)
-          self.treeview_update.set_sensitive(False)
+          self.label_downsize.set_text("\n")
+          if self.cache.keepCount() == 0:
+              self.notebook_details.set_sensitive(False)
+              self.treeview_update.set_sensitive(False)
           self.button_install.set_sensitive(False)
           self.button_close.grab_default()
           self.textview_changes.get_buffer().set_text("")
@@ -557,11 +608,11 @@ class UpdateManager(SimpleGtkbuilderApp):
   def on_button_settings_clicked(self, widget):
     #print "on_button_settings_clicked"
     try:
-        apt_pkg.PkgSystemUnLock()
+        apt_pkg.pkgsystem_unlock()
     except SystemError:
         pass
     cmd = ["/usr/bin/gksu", 
-           "--desktop", "/usr/share/applications/software-properties.desktop", 
+           "--desktop", "/usr/share/applications/software-properties-gtk.desktop", 
            "--", "/usr/bin/software-properties-gtk","--open-tab","2",
            "--toplevel", "%s" % self.window_main.window.xid ]
     self.window_main.set_sensitive(False)
@@ -591,25 +642,27 @@ class UpdateManager(SimpleGtkbuilderApp):
                                             req.size_needed,
                                             req.dir))
         return
-    except SystemError, e:
-        logging.exception("free space check failed")
     self.invoke_manager(INSTALL)
     
-  def show_reboot_required_dialog(self):
-    self.dialog_reboot.set_transient_for(self.window_main)
-    self.dialog_reboot.set_title("")
-    res = self.dialog_reboot.run()
-    self.dialog_reboot.hide()
-    if res == gtk.RESPONSE_OK:
-      try:
-          bus = dbus.SessionBus()
-          proxy_obj = bus.get_object("org.gnome.SessionManager",
-				     "/org/gnome/SessionManager")
-          iface = dbus.Interface(proxy_obj, "org.gnome.SessionManager")
-          iface.RequestReboot()
-          # FIXME: try sesion restart with hal?
-      except dbus.DBusException, e:
-          pass
+  def on_button_restart_required_clicked(self, button=None):
+      self._request_reboot_via_session_manager()
+
+  def show_reboot_required_info(self):
+    self.frame_restart_required.show()
+    self.label_restart_required.set_text(_("The computer needs to restart to "
+                                       "finish installing updates. Please "
+                                       "save your work before continuing."))
+
+  def _request_reboot_via_session_manager(self):
+    try:
+        bus = dbus.SessionBus()
+        proxy_obj = bus.get_object("org.gnome.SessionManager",
+                                   "/org/gnome/SessionManager")
+        iface = dbus.Interface(proxy_obj, "org.gnome.SessionManager")
+        iface.RequestReboot()
+        # FIXME: try sesion restart with hal?
+    except dbus.DBusException, e:
+        pass
 
   def invoke_manager(self, action):
     # check first if no other package manager is runing
@@ -618,32 +671,74 @@ class UpdateManager(SimpleGtkbuilderApp):
     os.environ["APT_LISTCHANGES_FRONTEND"]="none"
 
     # Do not suspend during the update process
-    (dev, cookie) = inhibit_sleep()
+    (self.sleep_dev, self.sleep_cookie) = inhibit_sleep()
 
     # set window to insensitive
     self.window_main.set_sensitive(False)
     self.window_main.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.WATCH))
-
+#
     # do it
     if action == UPDATE:
         self.install_backend.update()
     elif action == INSTALL:
-        has_reboot = os.path.exists(REBOOT_REQUIRED_FILE)
-        # do it
-        self.install_backend.commit(self.cache)
-        # check if there is a new reboot required notification
-        if not has_reboot and os.path.exists(REBOOT_REQUIRED_FILE):
-            self.show_reboot_required_dialog()
-    s = _("Reading package information")
-    self.label_cache_progress_title.set_label("<b><big>%s</big></b>" % s)
-    self.fillstore()
+        # If the progress dialog should be closed automatically afterwards
+        gconfclient =  gconf.client_get_default()
+        close_on_done = gconfclient.get_bool("/apps/update-manager/"
+                                             "autoclose_install_window")
+        # Get the packages which should be installed and update
+        pkgs_install = []
+        pkgs_upgrade = []
+        for pkg in self.cache:
+            if pkg.marked_install:
+                pkgs_install.append(pkg.name)
+            elif pkg.marked_upgrade:
+                pkgs_upgrade.append(pkg.name)
+        self.install_backend.commit(pkgs_install, pkgs_upgrade, close_on_done)
+
+  def _on_backend_done(self, backend, action, authorized):
+    # check if there is a new reboot required notification
+    if (action == INSTALL and
+        os.path.exists(REBOOT_REQUIRED_FILE)):
+        self.show_reboot_required_info()
+    if authorized:
+        msg = _("Reading package information")
+        self.label_cache_progress_title.set_label("<b><big>%s</big></b>" % msg)
+        self.fillstore()
 
     # Allow suspend after synaptic is finished
-    if cookie != False:
-        allow_sleep(dev, cookie)
+    if self.sleep_cookie:
+        allow_sleep(self.sleep_dev, self.sleep_cookie)
+        self.sleep_cookie = self.sleep_dev = None
     self.window_main.set_sensitive(True)
     self.window_main.window.set_cursor(None)
 
+  def _on_network_alert(self, watcher, state):
+      # do not set the buttons to sensitive/insensitive until NM
+      # can deal with dialup connections properly
+      if state == NM_STATE_CONNECTING:
+          self.label_offline.set_text(_("Connecting..."))
+          #self.button_reload.set_sensitive(False)
+          self.refresh_updates_count()
+          self.hbox_offline.show()
+          self.vbox_alerts.show()
+      elif state == NM_STATE_CONNECTED:
+          #self.button_reload.set_sensitive(True)
+          self.refresh_updates_count()
+          self.hbox_offline.hide()
+      else:
+          self.label_offline.set_text(_("You may not be able to check for updates or download new updates."))
+          #self.button_reload.set_sensitive(False)
+          self.refresh_updates_count()
+          self.hbox_offline.show()
+          self.vbox_alerts.show()
+          
+  def _on_battery_alert(self, watcher, on_battery):
+      if on_battery:
+          self.hbox_battery.show()
+          self.vbox_alerts.show()
+      else:
+          self.hbox_battery.hide()    
+
   def row_activated(self, treeview, path, column):
       iter = self.store.get_iter(path)
       pkg = self.store.get_value(iter, LIST_PKG)
@@ -651,18 +746,18 @@ class UpdateManager(SimpleGtkbuilderApp):
       if pkg is not None:
           return
       self.setBusy(True)
-      actiongroup = apt_pkg.GetPkgActionGroup(self.cache._depcache)
+      actiongroup = apt_pkg.ActionGroup(self.cache._depcache)
       for pkg in self.list.pkgs[origin]:
-          if pkg.markedInstall or pkg.markedUpgrade:
+          if pkg.marked_install or pkg.marked_upgrade:
               #print "marking keep: ", pkg.name
-              pkg.markKeep()
+              pkg.mark_keep()
           elif not (pkg.name in self.list.held_back):
               #print "marking install: ", pkg.name
-              pkg.markInstall(autoFix=False,autoInst=False)
+              pkg.mark_install(autoFix=False,autoInst=False)
       # check if we left breakage
-      if self.cache._depcache.BrokenCount:
-          Fix = apt_pkg.GetPkgProblemResolver(self.cache._depcache)
-          Fix.ResolveByKeep()
+      if self.cache._depcache.broken_count:
+          Fix = apt_pkg.ProblemResolver(self.cache._depcache)
+          Fix.resolve_by_keep()
       self.refresh_updates_count()
       self.treeview_update.queue_draw()
       del actiongroup
@@ -679,13 +774,13 @@ class UpdateManager(SimpleGtkbuilderApp):
         return False
     self.setBusy(True)
     # update the cache
-    if pkg.markedInstall or pkg.markedUpgrade:
-        pkg.markKeep()
-        if self.cache._depcache.BrokenCount:
-            Fix = apt_pkg.GetPkgProblemResolver(self.cache._depcache)
-            Fix.ResolveByKeep()
+    if pkg.marked_install or pkg.marked_upgrade:
+        pkg.mark_keep()
+        if self.cache._depcache.broken_count:
+            Fix = apt_pkg.ProblemResolver(self.cache._depcache)
+            Fix.resolve_by_keep()
     else:
-        pkg.markInstall()
+        pkg.mark_install()
     self.treeview_update.queue_draw()
     self.refresh_updates_count()
     self.setBusy(False)
@@ -711,6 +806,7 @@ class UpdateManager(SimpleGtkbuilderApp):
     #print "on_window_main_size_allocate", width, height
     self.label_main_details.set_size_request(width - border_space ,-1)
     self.label_header.set_size_request(width - border_space,-1)
+    self.label_downsize.set_size_request(width - border_space,-1)
 
   def exit(self):
     """ exit the application, save the state """
@@ -764,6 +860,8 @@ class UpdateManager(SimpleGtkbuilderApp):
         sys.exit(1)
     self.store.clear()
     self.list = UpdateList(self)
+    while gtk.events_pending():
+        gtk.main_iteration()
     # fill them again
     try:
         self.list.update(self.cache)
@@ -784,6 +882,8 @@ class UpdateManager(SimpleGtkbuilderApp):
         dialog.run()
         dialog.destroy()
     if self.list.num_updates > 0:
+      #self.treeview_update.set_model(None)
+      self.scrolledwindow_update.show()
       origin_list = self.list.pkgs.keys()
       origin_list.sort(lambda x,y: cmp(x.importance,y.importance))
       origin_list.reverse()
@@ -792,10 +892,13 @@ class UpdateManager(SimpleGtkbuilderApp):
                            origin.description, None, origin,True])
         for pkg in self.list.pkgs[origin]:
           name = xml.sax.saxutils.escape(pkg.name)
-          if not pkg.isInstalled:
+          if not pkg.is_installed:
               name += _(" (New install)")
           summary = xml.sax.saxutils.escape(pkg.summary)
-          contents = "<b>%s</b>\n<small>%s</small>" % (name, summary)
+          if self.summary_before_name:
+              contents = "%s\n<small>%s</small>" % (summary, name)
+          else:
+              contents = "<b>%s</b>\n<small>%s</small>" % (name, summary)
           #TRANSLATORS: the b stands for Bytes
           size = _("(Size: %s)") % humanize_size(pkg.packageSize)
           if pkg.installedVersion != None:
@@ -809,9 +912,11 @@ class UpdateManager(SimpleGtkbuilderApp):
           else:
               contents = "%s <small>%s</small>" % (contents, size)
           self.store.append([contents, pkg.name, pkg, None, True])
+      self.treeview_update.set_model(self.store)
     self.update_count()
     self.setBusy(False)
     self.check_all_updates_installable()
+    self.refresh_updates_count()
     return False
 
   def dist_no_longer_supported(self, meta_release):
@@ -844,6 +949,11 @@ class UpdateManager(SimpleGtkbuilderApp):
 
   def on_button_dist_upgrade_clicked(self, button):
       #print "on_button_dist_upgrade_clicked"
+      if self.new_dist.upgrade_broken:
+          return self.error(
+              _("Release upgrade not possible right now"),
+              _("The release upgrade can not be performed currently, "
+                "please try again later. The server reported: '%s'") % self.new_dist.upgrade_broken)
       fetcher = DistUpgradeFetcherGtk(new_dist=self.new_dist, parent=self, progress=GtkProgress.GtkFetchProgress(self, _("Downloading the release upgrade tool")))
       if self.options.sandbox:
           fetcher.run_options.append("--sandbox")
@@ -859,7 +969,7 @@ class UpdateManager(SimpleGtkbuilderApp):
   def initCache(self): 
     # get the lock
     try:
-        apt_pkg.PkgSystemLock()
+        apt_pkg.pkgsystem_lock()
     except SystemError, e:
         pass
         #d = gtk.MessageDialog(parent=self.window_main,
@@ -904,7 +1014,7 @@ class UpdateManager(SimpleGtkbuilderApp):
         dialog.destroy()
         sys.exit(1)
     else:
-        self.progress.hide()
+        self.progress.all_done()
 
   def check_auto_update(self):
       # Check if automatic update is enabled. If not show a dialog to inform
@@ -913,7 +1023,7 @@ class UpdateManager(SimpleGtkbuilderApp):
       if remind == False:
           return
 
-      update_days = apt_pkg.Config.FindI("APT::Periodic::Update-Package-Lists")
+      update_days = apt_pkg.Config.find_i("APT::Periodic::Update-Package-Lists")
       if update_days < 1:
           self.dialog_manual_update.set_transient_for(self.window_main)
           self.dialog_manual_update.set_title("")
@@ -964,4 +1074,5 @@ class UpdateManager(SimpleGtkbuilderApp):
 
     self.fillstore()
     self.check_auto_update()
+    self.alert_watcher.check_alert_state()
     gtk.main()
