@@ -146,11 +146,14 @@ deb http://ports.ubuntu.com/ubuntu-ports/ hardy-security main restricted
         d = DistUpgradeController(v,datadir=self.testdir)
         for scheme in ["ftp","http"]:
             entry = "deb %s://archive.ubuntu.com/ubuntu/ hardy main universe restricted multiverse" % scheme
-            self.assertTrue(d._sourcesListEntryDownloadable(SourceEntry(entry)))
+            self.assertTrue(d._sourcesListEntryDownloadable(SourceEntry(entry)),
+                            "entry '%s' not downloadable" % entry)
             entry = "deb %s://archive.ubuntu.com/ubuntu/ warty main universe restricted multiverse" % scheme
-            self.assertFalse(d._sourcesListEntryDownloadable(SourceEntry(entry)))
+            self.assertFalse(d._sourcesListEntryDownloadable(SourceEntry(entry)),
+                            "entry '%s' not downloadable" % entry)
             entry = "deb %s://archive.ubuntu.com/ubuntu/ xxx main" % scheme
-            self.assertFalse(d._sourcesListEntryDownloadable(SourceEntry(entry)))
+            self.assertFalse(d._sourcesListEntryDownloadable(SourceEntry(entry)),
+                            "entry '%s' not downloadable" % entry)
 
     def testEOL2EOLUpgrades(self):
         " test upgrade from EOL release to EOL release "
@@ -175,7 +178,7 @@ deb http://old-releases.ubuntu.com/ubuntu hoary-security main restricted
 """)
 
     def testEOL2SupportedWithMirrorUpgrade(self):
-        " test upgrade from a EOL release to a supported release with mirroor"
+        " test upgrade from a EOL release to a supported release with mirror"
         os.environ["LANG"] = "de_DE.UTF-8"
         v = DistUpgradeViewNonInteractive()
         d = DistUpgradeController(v,datadir=self.testdir)
@@ -184,17 +187,17 @@ deb http://old-releases.ubuntu.com/ubuntu hoary-security main restricted
         apt_pkg.Config.Set("Dir::Etc::sourceparts",os.path.join(self.testdir,"sources.list.d"))
         v = DistUpgradeViewNonInteractive()
         d = DistUpgradeController(v,datadir=self.testdir)
-        d.fromDist = "feisty"
-        d.toDist = "gutsy"
+        d.fromDist = "gutsy"
+        d.toDist = "hardy"
         d.openCache(lock=False)
         res = d.updateSourcesList()
         self.assert_(res == True)
         self._verifySources("""
 # main repo
-deb http://de.archive.ubuntu.com/ubuntu gutsy main restricted multiverse universe
-deb-src http://de.archive.ubuntu.com/ubuntu gutsy main restricted multiverse
+deb http://de.archive.ubuntu.com/ubuntu hardy main restricted multiverse universe
+deb-src http://de.archive.ubuntu.com/ubuntu hardy main restricted multiverse
 
-deb http://de.archive.ubuntu.com/ubuntu gutsy-security main restricted
+deb http://de.archive.ubuntu.com/ubuntu hardy-security main restricted
 """)
 
     def testEOL2SupportedUpgrade(self):
@@ -207,17 +210,17 @@ deb http://de.archive.ubuntu.com/ubuntu gutsy-security main restricted
         apt_pkg.Config.Set("Dir::Etc::sourceparts",os.path.join(self.testdir,"sources.list.d"))
         v = DistUpgradeViewNonInteractive()
         d = DistUpgradeController(v,datadir=self.testdir)
-        d.fromDist = "feisty"
-        d.toDist = "gutsy"
+        d.fromDist = "gutsy"
+        d.toDist = "hardy"
         d.openCache(lock=False)
         res = d.updateSourcesList()
         self.assert_(res == True)
         self._verifySources("""
 # main repo
-deb http://archive.ubuntu.com/ubuntu gutsy main restricted multiverse universe
-deb-src http://archive.ubuntu.com/ubuntu gutsy main restricted multiverse
+deb http://archive.ubuntu.com/ubuntu hardy main restricted multiverse universe
+deb-src http://archive.ubuntu.com/ubuntu hardy main restricted multiverse
 
-deb http://archive.ubuntu.com/ubuntu gutsy-security main restricted
+deb http://archive.ubuntu.com/ubuntu hardy-security main restricted
 """)
 
     def test_partner_update(self):
@@ -242,7 +245,36 @@ deb http://security.ubuntu.com/ubuntu/ gutsy-security main restricted universe m
 
 deb http://archive.canonical.com/ubuntu gutsy partner
 """)
-        
+
+    def test_apt_cacher_and_apt_bittorent(self):
+        """
+        test transition of apt-cacher/apt-torrent uris
+        """
+        shutil.copy(os.path.join(self.testdir,"sources.list.apt-cacher"),
+                    os.path.join(self.testdir,"sources.list"))
+        apt_pkg.Config.Set("Dir::Etc::sourceparts",os.path.join(self.testdir,"sources.list.d"))
+        v = DistUpgradeViewNonInteractive()
+        d = DistUpgradeController(v,datadir=self.testdir)
+        d.openCache(lock=False)
+        res = d.updateSourcesList()
+        self.assert_(res == True)
+
+        # now test the result
+        self._verifySources("""
+deb http://localhost:9977/security.ubuntu.com/ubuntu gutsy-security main restricted
+deb http://localhost:9977/archive.canonical.com/ubuntu gutsy partner
+deb http://localhost:9977/us.archive.ubuntu.com/ubuntu/ gutsy main
+deb http://localhost:9977/archive.ubuntu.com/ubuntu/ gutsy main
+
+deb http://archive.ubuntu.com/ubuntu/ gutsy main restricted multiverse universe
+deb-src http://archive.ubuntu.com/ubuntu/ gutsy main restricted multiverse
+
+deb http://security.ubuntu.com/ubuntu/ gutsy-security main restricted
+deb http://security.ubuntu.com/ubuntu/ gutsy-security universe
+
+deb http://archive.canonical.com/ubuntu gutsy partner
+""")
+
         
     def _verifySources(self, expected):
         sources_list = open(apt_pkg.Config.FindFile("Dir::Etc::sourcelist")).read()
